@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2005 Zope Corporation and Contributors. All Rights Reserved.
+# Copyright (c) 2005 Zope Foundation and Contributors.
 #
 # This software is subject to the provisions of the Zope Public License,
 # Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
@@ -16,15 +16,21 @@ import os.path
 from zope import interface
 from zope import schema
 from zope.configuration import fields
-from i18n import _
 
+from zope.mimetype.i18n import _
 from zope.mimetype import codec
 from zope.mimetype import interfaces
-from zope.mimetype import types
+from zope.mimetype import mtypes
+
+try:
+    from zope.browserresource.metaconfigure import icon
+except ImportError:
+    def icon(*args):
+        import warnings
+        warnings.warn("No icon support: zope.browserresource is not installed")
 
 import zope.component.zcml
 import zope.component.interface
-import zope.app.publisher.browser.icon
 
 
 class IMimeTypesDirective(interface.Interface):
@@ -53,13 +59,13 @@ class IMimeTypesDirective(interface.Interface):
 def mimeTypesDirective(_context, file, module):
     codec.initialize(_context)
     directory = os.path.dirname(file)
-    data = types.read(file)
+    data = mtypes.read(file)
     provides = interfaces.IContentTypeInterface
-    for name, info in data.iteritems():
+    for name, info in data.items():
         iface = getattr(module, name, None)
         if iface is None:
             # create missing interface
-            iface = types.makeInterface(
+            iface = mtypes.makeInterface(
                 name, info, getattr(module, "__name__", None))
             setattr(module, name, iface)
         # Register the interface as a utility:
@@ -76,10 +82,9 @@ def mimeTypesDirective(_context, file, module):
                 callable = zope.component.zcml.handler,
                 args = ('registerUtility', iface, provides, mime_type),
                 )
-        icon = os.path.join(directory, info[3])
-        if icon and os.path.isfile(icon):
-            zope.app.publisher.browser.icon.IconDirective(
-                _context, "zmi_icon", iface, icon)
+        icon_path = os.path.join(directory, info[3])
+        if icon_path and os.path.isfile(icon_path):
+            icon(_context, "zmi_icon", iface, icon_path)
 
 
 class ICodecDirective(interface.Interface):
